==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/core/ivectorfieldglyphpipeline.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "ivectorfieldglyphpipeline.h"


#include "idatalimits.h"
#include "ierror.h"
#include "ireplicatedpolydata.h"
#include "iresampleimagedatafilter.h"
#include "ivectorglyphfilter.h"
#include "ivectorfieldviewsubject.h"

//
//  Templates (needed for some compilers)
//
#include "iarraytemplate.h"
#include "igenericfiltertemplate.h"
#include "iviewsubjectpipelinetemplate.h"


//
// iVectorFieldGlyphPipeline class
//
iVectorFieldGlyphPipeline::iVectorFieldGlyphPipeline(iVectorFieldViewSubject *s) : iViewSubjectPipeline(s,1)
{
	mParent = s;

	//
	//  Do VTK stuff
	//	
	mDataReplicated = this->CreateFilter<iReplicatedPolyData>();
	mGlyph = this->CreateFilter<iVectorGlyphFilter>();
	mFilter = this->CreateFilter<iResampleImageDataFilter>();
	
	mGlyph->SetInput(mFilter->GetOutput());
	mDataReplicated->SetInput(mGlyph->GetOutput());

	this->UpdateContents(_All);
}


iVectorFieldGlyphPipeline::~iVectorFieldGlyphPipeline()
{
}


void iVectorFieldGlyphPipeline::ProduceOutput()
{
	vtkDataSet *input = this->GetInput();
	vtkPolyData *output = this->GetOutput();

	if(mFilter!=0 && input->IsA("vtkImageData"))
	{
		vtkImageData *inp = vtkImageData::SafeDownCast(input);
		if(mFilter->GetInput() != inp)
		{
			mFilter->SetInput(inp);
		}
	}
	else
	{
		if(mGlyph->GetInput() != input)
		{
			mGlyph->SetInput(input);
		}
	}

	//
	//  Needed so that the glyph size is correct
	//
	this->UpdateSize();
	//
	//  Update the pipeline
	//
	mDataReplicated->Update();
	output->ShallowCopy(mDataReplicated->GetOutput());
}


float iVectorFieldGlyphPipeline::GetContentsMemorySize() const
{
	float s = 0.0f;
	s += mDataReplicated->GetMemorySize();
	s += mGlyph->GetMemorySize();
	if(mFilter != 0) s += mFilter->GetMemorySize();
	return s;
}


void iVectorFieldGlyphPipeline::UpdateContents(int n, int)
{
	if(n==_All || n==_Replicas) this->UpdateReplicas();
	if(n==_All || n==_SampleRate) this->UpdateSampleRate();
	if(n==_All || n==_Size) this->UpdateSize();
}


void iVectorFieldGlyphPipeline::UpdateSize()
{
	//
	//  Do not update unless necessary
	//
	if(mParent->CanBeShown())
	{
		double ns = 10.0*mParent->GetGlyphSize()*2.0/this->GetLimits()->GetUpperLimit(mParent->GetDataOffset()); // 2.0 is the box size
		mGlyph->SetScaleFactor(ns);
		this->Modified();
	}
}


void iVectorFieldGlyphPipeline::UpdateSampleRate()
{ 
	if(mFilter != 0) mFilter->SetSampleRate(mParent->GetGlyphSampleRate(),mParent->GetGlyphSampleRate(),mParent->GetGlyphSampleRate());
	this->Modified();
}


void iVectorFieldGlyphPipeline::UpdateReplicas()
{
	mDataReplicated->Modified();
	this->Modified();
}


void iVectorFieldGlyphPipeline::SyncWithData(const iDataSyncRequest &)
{
	this->UpdateSize();
}

==> ifrit_4.1.2.orig.tar.gz: ifrit-4.1.2/core/ivectorfieldglyphpipeline.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "ivectorfieldglyphpipeline.h"


#include "idatalimits.h"
#include "ierror.h"
#include "ireplicatedpolydata.h"
#include "iresampleimagedatafilter.h"
#include "ivectorglyphfilter.h"
#include "ivectorfieldviewsubject.h"

//
//  Templates (needed for some compilers)
//
#include "iarray.tlh"
#include "igenericfilter.tlh"
#include "iviewsubjectpipeline.tlh"


iPipelineKeyDefineMacro(iVectorFieldGlyphPipeline,GlyphBaseSize);


//
// iVectorFieldGlyphPipeline class
//
iVectorFieldGlyphPipeline::iVectorFieldGlyphPipeline(iVectorFieldViewInstance *owner) : iFieldGlyphPipeline(owner)
{
	mOwner = owner;

	//
	//  Do VTK stuff
	//	
	mGlyphFilter = this->CreateFilter<iVectorGlyphFilter>();
	mGlyphFilter->SetInputConnection(mResampleFilter->GetOutputPort());

	this->CompletePipeline(mGlyphFilter->GetOutputPort());
	this->UpdateContents();
}


iVectorFieldGlyphPipeline::~iVectorFieldGlyphPipeline()
{
}


void iVectorFieldGlyphPipeline::SetGlyphFilterInput(vtkDataSet *input)
{
	if(mGlyphFilter->InputData() != input)
	{
		mGlyphFilter->SetInputData(input);
	}
}


void iVectorFieldGlyphPipeline::SetGlyphFilterScale(double s)
{
	mGlyphFilter->SetScaleFactor(s);
}



void iVectorFieldGlyphPipeline::UpdateGlyphBaseSize()
{
	mGlyphFilter->SetIncludeVerts(mOwner->GetGlyphBaseSize() > 1);
	this->Modified();
}
